@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use strictures 2;
 use List::SomeUtils qw(first_index);
@@ -68,7 +68,7 @@ sub _build_phrase {
 
 sub _drum_parts ($self, $note) {
     my $part;
-    if ($note == 99) {
+    if (defined $self->trigger && $note == $self->trigger) {
         $part = $self->phrase;
     }
     else {
@@ -81,9 +81,6 @@ sub _drum_parts ($self, $note) {
 }
 sub drums ($self, $device, $dt, $event) {
     my ($ev, $chan, $note, $val) = $event->@*;
-    return 0 if defined $self->trigger && $note != $self->trigger;
-    return 0 if defined $self->value && $val != $self->value;
-
     my $part = $self->_drum_parts($note);
     my $d = MIDI::Drummer::Tiny->new(
         bpm  => $self->bpm,
@@ -114,7 +111,7 @@ MIDI::RtController::Filter::Drums - RtController drum filters
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
@@ -132,6 +129,8 @@ version 0.0300
   my $filter = MIDI::RtController::Filter::Drums->new(rtc => $controller);
 
   $filter->phrase(\&my_phrase);
+  $filter->trigger(99); # trigger the phrase
+  $filter->bars(8);
 
   $controller->add_filter('drums', note_on => $filter->curry::drums);
 
@@ -233,16 +232,18 @@ should be applied.
 
 The F<eg/*.pl> program(s) in this distribution
 
-L<MIDI::RtController::Filter::Tonal>
+L<MIDI::RtController::Filter::Tonal> - Related module
 
-L<MIDI::RtController::Filter::Math>
+L<MIDI::RtController::Filter::Math> - Related module
 
-L<MIDI::RtController::Filter::CC>
+L<MIDI::RtController::Filter::CC> - Related module
 
 L<List::SomeUtils>
 
 L<MIDI::Drummer::Tiny>
 
+L<MIDI::RtController>
+
 L<MIDI::RtMidi::ScorePlayer>
 
 L<Moo>
